==> wcomponents-theme-1.0.5.jar: theme/wcomponents-theme/scripts_debug/wc/i18n/fr-CA.js <==
define({
	"asciimap":"{\"\\u00e0\\u00e2\\u00e4\": \"a\",\"\\u00e8\\u00e9\\u00ea\\u00eb\": \"e\",\"\\u00ee\\u00ef\": \"i\",\"\\u00f4\": \"o\",\"\\u00f9\\u00fb\\u00fc\": \"u\",\"\\u00e7\": \"c\",\"\\u00e6\": \"ae\",\"\\u0153\": \"oe\"}",
	"btt0":"Back to top (press the ESCAPE key to hide this)",
	"cbg1":"Sélectionner une ou plusieurs options",
	"cbg2":"Appuyez sur SHIFT + cliquez pour exécuter une gamme d'options",
	"chi1":"sélectionné",
	"chi2":"non choisi",
	"cm0":"Développer tout",
	"cm1":"Cet élément doit avoir une étiquette",
	"cm2":"requis",
	"cm3":"Changer la valeur ou la sélection de cette composante fera en sorte que tous vos changements seront sauvegardés immédiatement.",
	"cm4":"[a-zA-Z]",
	"cu1":"has unsaved changes. Would you like to discard them?",
	"cu2":"This page",
	"day0":"Dimanche",
	"day1":"Lundi",
	"day2":"Mardi",
	"day3":"Mercredi",
	"day4":"Jeudi",
	"day5":"Vendredi",
	"day6":"Samedi",
	"df0":"Raccourcis : t/y/m = aujourd'hui/hier/demain. \\n+/-N = +/-N jours à compter d'aujourd'hui. P. ex. +7.",
	"df1":"d M yy,d M yyyy,d MON yy,d MON yyyy,ddMMyy,ddMMyyyy,dMONyy,dMONyyyy,yyyy-MM-dd,yyyyMMdd",
	"df10":"aller au mois précédent",
	"df11":"aller au mois suivant",
	"df12":"aller à la date d'aujourd'hui",
	"df13":"Fermer le calendrier",
	"df2":"M y, MON y,M y,MON y,MONy,MMyy,Myyyy,yyyyMM,yyyyM,y,d M,M,d MON,d M,dMON,ddMM,ddMON,MON,d,dd yyyy,ddyyyy,ddyy,dd yy",
	"df3":"dd MON yyyy",
	"df6":"yyyy",
	"df7":"Mois",
	"df8":"Anné",
	"df9":"Calendrier sélecteur de date",
	"dlg0":"Dialogue sans titre",
	"dlg1":"Touche CTRL + touche FLÉCHÉE pour déplacer le dialogue",
	"dlg2":"Touche FLÉCHÉE DROIT ou touche FLÉCHÉE BAS pour agrandir le dialogue, touche FLÉCHÉE GAUCHE ou touche FLÉCHÉE HAUT pour raccourcir le dialogue",
	"dlg3":"Fermer le dialogue",
	"dlg4":"Maximise/restore dialog",
	"iet0":"Rotate",
	"iet1":"Left",
	"iet10":"Image Editor",
	"iet11":"Left 90º",
	"iet12":"Right 90º",
	"iet2":"Right",
	"iet3":"Move",
	"iet4":"Left",
	"iet5":"Right",
	"iet6":"Up",
	"iet7":"Down",
	"iet8":"Zoom",
	"iet9":"In",
	"ietA":"Out",
	"ietB":"Reset",
	"ietC":"Cancel",
	"ietD":"Save",
	"ietE":"Photo",
	"ietF":"Speed",
	"ietF1":"Your browser does not support webcam capture",
	"lang":"fr",
	"load1":"Chargement en cours",
	"locale":"fr-CA",
	"lsc1":"move to top",
	"lsc2":"move up",
	"lsc3":"move down",
	"lsc4":"move to bottom",
	"lstldr0":"Une erreur est survenue lors du chargement de la liste%s",
	"lstldr1":"Réessayer",
	"mb0":"Une erreur s'est produite",
	"mb1":"Avertissement",
	"mb2":"Information",
	"mb3":"Réussi",
	"media1":"Commencer la lecture",
	"media2":"pause",
	"menu1":"wc_coleast",
	"menu2":"wc_colwest",
	"menu3":"Fermer le menu",
	"mfc0":"Ajouter un élément à :",
	"mfc1":"Supprimer l'élément. Appuyez sur Shift + cliquez sur le bouton Enlever pour supprimer tous les éléments.",
	"mfc2":"select an option",
	"mfc3":"Vous avez atteint le maximum d'options à sélectionner.",
	"mfu0":"Le fichier sélectionné est trop volumineux (%1$s %3$s).\\nLa taille de fichier maximale est de %2$s %3$s.",
	"mfu1":"Le type de fichier sélectionné n'est pas accepté.\\nSeuls les types de fichier suivants sont acceptés : %s.",
	"mfu2":"Si vous naviguez à l'extérieur de cette page, le téléchargement de fichier en cours sera annulé.\\nVoulez-vous continuer?",
	"mfu3":"octets",
	"mfu4":"sélecteur de fichier",
	"mfu5":"kilooctets",
	"mfu6":"megaoctets",
	"mfu7":"gigaoctets",
	"mfu8":"Vous êtes sûr que vous voulez supprimer ce fichier ?",
	"mfu9":"Vous ne pouvez pas joindre plusieurs fichiers, le maximum autorisé est %2$s.",
	"mnth0":"janvier",
	"mnth1":"février",
	"mnth2":"mars",
	"mnth3":"avril",
	"mnth4":"mai",
	"mnth5":"juin",
	"mnth6":"juillet",
	"mnth7":"août",
	"mnth8":"septembre",
	"mnth9":"octobre",
	"mnthA":"novembre",
	"mnthB":"décembre",
	"mnthabbr0":"Janv",
	"mnthabbr1":"Févr",
	"mnthabbr2":"Mars",
	"mnthabbr3":"Avril",
	"mnthabbr4":"Mai",
	"mnthabbr5":"Juin",
	"mnthabbr6":"Juil",
	"mnthabbr7":"Août",
	"mnthabbr8":"Sept",
	"mnthabbr9":"Oct",
	"mnthabbrA":"Nov",
	"mnthabbrB":"Déc",
	"msp0":"Ajouter ",
	"msp1":"Ajouter tous ",
	"msp2":"Supprimer",
	"msp3":"Supprimer tous",
	"mx0":"%d de caractères restants",
	"p1":"Untitled Section",
	"rbg1":"Sélectionner une option",
	"rt0":"Vous devez avoir JavaScript activé pour utiliser cette application.",
	"sbxs1":"abcdefghijklmnopqrstuvwxyzéàèùâêîôûäïüç0123456789~`!@#$%^&*()-_=+[{]}\\|;:'\",<.>/? ",
	"sk1":"Aller à ",
	"tble1":"Omission",
	"tble13":"Sélectionner/désélectionner tout",
	"tble4":"Détailler/occulter des sections",
	"tble5":"tri décroissant",
	"tble6":"tri croissant",
	"tble7":"Triable mais non trié",
	"tog1":"Sélectionner :",
	"tog2":"Tous",
	"tog3":"Aucun",
	"tog4":"Sélectionner tout",
	"tog5":"Réduire tout",
	"tre1":"Afficher/masquer le contenu",
	"trs1":"Sélectionner une ou plusieurs lignes",
	"trs2":"Sélectionner une ligne",
	"twm1":"Avertissement",
	"twm2":"<p>Votre session sur le portail sera automatiquement fermée dans les %s prochaines minutes.</p><p>Raison : le serveur n'a enregistré aucune activité depuis un certain temps.</p><p>Pour remettre le compteur de session à zéro, vous pouvez :</p><ul><li>Enregistrer votre travail ou</li><li>Consulter une autre page.</li></ul>",
	"twm3":"Session expirée",
	"twm4":"<p>Votre session sur le portail est expirée.</p><p>Certaines modifications peuvent ne pas avoir été enregistrées.</p><p>Pour ouvrir une nouvelle session sur le portail, vous pouvez :</p><ul><li>Naviguer vers la page d'accueil du portail ou</li><li>Fermer cette fenêtre et ouvrir une nouvelle application sur le portail.</li></ul>",
	"wdtp0":"Première page",
	"wdtp1":"Page précédente",
	"wdtp10":"tous",
	"wdtp2":"Page suivante",
	"wdtp3":"Dernière page",
	"wdtp4":"Page",
	"wdtp5":"1 résultat",
	"wdtp6":"^ sur # résultats",
	"wdtp7":"^ - | sur # résultats",
	"wdtp9":"Lignes"
});

==> wcomponents-theme-1.1.4.jar: theme/wcomponents-theme/scripts_debug/wc/i18n/fr-CA.js <==
define({
	"asciimap":"{\"\\u00e0\\u00e2\\u00e4\": \"a\",\"\\u00e8\\u00e9\\u00ea\\u00eb\": \"e\",\"\\u00ee\\u00ef\": \"i\",\"\\u00f4\": \"o\",\"\\u00f9\\u00fb\\u00fc\": \"u\",\"\\u00e7\": \"c\",\"\\u00e6\": \"ae\",\"\\u0153\": \"oe\"}",
	"btt0":"Back to top (press the ESCAPE key to hide this)",
	"cbg1":"Sélectionner une ou plusieurs options",
	"cbg2":"Appuyez sur SHIFT + cliquez pour exécuter une gamme d'options",
	"chi1":"sélectionné",
	"chi2":"non choisi",
	"cm0":"Développer tout",
	"cm1":"Cet élément doit avoir une étiquette",
	"cm2":"requis",
	"cm3":"Changer la valeur ou la sélection de cette composante fera en sorte que tous vos changements seront sauvegardés immédiatement.",
	"cm4":"[a-zA-Z]",
	"cu1":"has unsaved changes. Would you like to discard them?",
	"cu2":"This page",
	"day0":"Dimanche",
	"day1":"Lundi",
	"day2":"Mardi",
	"day3":"Mercredi",
	"day4":"Jeudi",
	"day5":"Vendredi",
	"day6":"Samedi",
	"df0":"Raccourcis : t/y/m = aujourd'hui/hier/demain. +/-N = +/-N jours à compter d'aujourd'hui. P. ex. +7.",
	"df1":"d M yy,d M yyyy,d MON yy,d MON yyyy,ddMMyy,ddMMyyyy,dMONyy,dMONyyyy,yyyy-MM-dd,yyyyMMdd",
	"df10":"aller au mois précédent",
	"df11":"aller au mois suivant",
	"df12":"aller à la date d'aujourd'hui",
	"df13":"Fermer le calendrier",
	"df2":"M y, MON y,M y,MON y,MONy,MMyy,Myyyy,yyyyMM,yyyyM,y,d M,M,d MON,d M,dMON,ddMM,ddMON,MON,d,dd yyyy,ddyyyy,ddyy,dd yy",
	"df3":"dd MON yyyy",
	"df6":"yyyy",
	"df7":"Mois",
	"df8":"Anné",
	"df9":"Calendrier sélecteur de date",
	"dlg0":"Dialogue sans titre",
	"dlg1":"Touche CTRL + touche FLÉCHÉE pour déplacer le dialogue",
	"dlg2":"Touche FLÉCHÉE DROIT ou touche FLÉCHÉE BAS pour agrandir le dialogue, touche FLÉCHÉE GAUCHE ou touche FLÉCHÉE HAUT pour raccourcir le dialogue",
	"dlg3":"Fermer le dialogue",
	"dlg4":"Maximise/restore dialog",
	"iet0":"Rotate",
	"iet1":"Left",
	"iet10":"Image Editor",
	"iet11":"Left 90º",
	"iet12":"Right 90º",
	"iet2":"Right",
	"iet3":"Move",
	"iet4":"Left",
	"iet5":"Right",
	"iet6":"Up",
	"iet7":"Down",
	"iet8":"Zoom",
	"iet9":"In",
	"ietA":"Out",
	"ietB":"Reset",
	"ietC":"Cancel",
	"ietD":"Save",
	"ietE":"Photo",
	"ietF":"Speed",
	"ietF1":"Your browser does not support webcam capture",
	"lang":"fr",
	"load1":"Chargement en cours",
	"locale":"fr-CA",
	"lsc1":"move to top",
	"lsc2":"move up",
	"lsc3":"move down",
	"lsc4":"move to bottom",
	"lstldr0":"Une erreur est survenue lors du chargement de la liste%s",
	"lstldr1":"Réessayer",
	"mb0":"Une erreur s'est produite",
	"mb1":"Avertissement",
	"mb2":"Information",
	"mb3":"Réussi",
	"media1":"Commencer la lecture",
	"media2":"pause",
	"menu0":"wc_coleast",
	"menu1":"wc_colwest",
	"menu2":"Fermer le menu",
	"menu3":"Open",
	"mfc0":"Ajouter un élément à :",
	"mfc1":"Supprimer l'élément. Appuyez sur Shift + cliquez sur le bouton Enlever pour supprimer tous les éléments.",
	"mfc2":"select an option",
	"mfc3":"Vous avez atteint le maximum d'options à sélectionner.",
	"mfu0":"Le fichier sélectionné est trop volumineux (%1$s %3$s). La taille de fichier maximale est de %2$s %3$s.",
	"mfu1":"Le type de fichier sélectionné n'est pas accepté. Seuls les types de fichier suivants sont acceptés : %s.",
	"mfu2":"Si vous naviguez à l'extérieur de cette page, le téléchargement de fichier en cours sera annulé. Voulez-vous continuer?",
	"mfu3":"octets",
	"mfu4":"sélecteur de fichier",
	"mfu5":"kilooctets",
	"mfu6":"megaoctets",
	"mfu7":"gigaoctets",
	"mfu8":"Vous êtes sûr que vous voulez supprimer ce fichier ?",
	"mfu9":"Vous ne pouvez pas joindre plusieurs fichiers, le maximum autorisé est %2$s.",
	"mnth0":"janvier",
	"mnth1":"février",
	"mnth2":"mars",
	"mnth3":"avril",
	"mnth4":"mai",
	"mnth5":"juin",
	"mnth6":"juillet",
	"mnth7":"août",
	"mnth8":"septembre",
	"mnth9":"octobre",
	"mnthA":"novembre",
	"mnthB":"décembre",
	"mnthabbr0":"Janv",
	"mnthabbr1":"Févr",
	"mnthabbr2":"Mars",
	"mnthabbr3":"Avril",
	"mnthabbr4":"Mai",
	"mnthabbr5":"Juin",
	"mnthabbr6":"Juil",
	"mnthabbr7":"Août",
	"mnthabbr8":"Sept",
	"mnthabbr9":"Oct",
	"mnthabbrA":"Nov",
	"mnthabbrB":"Déc",
	"msp0":"Ajouter ",
	"msp1":"Ajouter tous ",
	"msp2":"Supprimer",
	"msp3":"Supprimer tous",
	"mx0":"%d de caractères restants",
	"p1":"Untitled Section",
	"rbg1":"Sélectionner une option",
	"rt0":"Vous devez avoir JavaScript activé pour utiliser cette application.",
	"sbxs1":"abcdefghijklmnopqrstuvwxyzéàèùâêîôûäïüç0123456789~`!@#$%^&*()-_=+[{]}\\|;:'\",<.>/? ",
	"sk1":"Aller à ",
	"tble1":"Omission",
	"tble13":"Sélectionner/désélectionner tout",
	"tble4":"Détailler/occulter des sections",
	"tble5":"tri décroissant",
	"tble6":"tri croissant",
	"tble7":"Triable mais non trié",
	"tog1":"Sélectionner :",
	"tog2":"Tous",
	"tog3":"Aucun",
	"tog4":"Sélectionner tout",
	"tog5":"Réduire tout",
	"tr0":"Expand/collapse this branch",
	"tre1":"Afficher/masquer le contenu",
	"trs1":"Sélectionner une ou plusieurs lignes",
	"trs2":"Sélectionner une ligne",
	"twm1":"Avertissement",
	"twm2":"<p>Votre session sur le portail sera automatiquement fermée dans les %s prochaines minutes.</p><p>Raison : le serveur n'a enregistré aucune activité depuis un certain temps.</p><p>Pour remettre le compteur de session à zéro, vous pouvez :</p><ul><li>Enregistrer votre travail ou</li><li>Consulter une autre page.</li></ul>",
	"twm3":"Session expirée",
	"twm4":"<p>Votre session sur le portail est expirée.</p><p>Certaines modifications peuvent ne pas avoir été enregistrées.</p><p>Pour ouvrir une nouvelle session sur le portail, vous pouvez :</p><ul><li>Naviguer vers la page d'accueil du portail ou</li><li>Fermer cette fenêtre et ouvrir une nouvelle application sur le portail.</li></ul>",
	"val_c0":"%s doit être complété.",
	"val_c1":"Ce champ",
	"val_c2":"%s n'est pas dans le format requis.",
	"val_c3":"%s doit avoir au moins un champ complété.",
	"val_c4":"%1$s ne doit pas avoir plus de %2$s options sélectionnées.",
	"val_c5":"%1$ doit avoir au moins %2$s options sélectionnées.",
	"val_c6":"%1$s et %2$s",
	"val_c7":"modifié avec succès.",
	"val_df0":"%1$s doit inclure au moins un jour (1-31) et/ou le mois (1-12 ou %2$s) et/ou de l'année (par exemple %3$d).",
	"val_df1":"%s doit être une date complète avec le jour, le mois et l'année.",
	"val_df2":"%1$s doit être sur ou après le %2$s.",
	"val_df3":"%1$s doit être sur ou avant le %2$s.",
	"val_df4":"de %1$s à %2$s",
	"val_mfc0":"%1$s must have at least %2$s values entered.",
	"val_mfc1":"%1$s must have no more than %2$s values entered.",
	"val_mfu0":"%s must have at least one file uploaded.",
	"val_msp0":"%1$s must have at least one option added to the %2$s list.",
	"val_msp1":"%1$s must have no more than %2$s options in the %3$s list.",
	"val_msp2":"%1$s must have at least %2$s options in the %3$s list.",
	"val_mx0":"%1$s is limited to %2$s characters and currently %3$d are entered.",
	"val_nf0":"%1$s must be at least %2$s.",
	"val_nf1":"%1$s must be no more than %2$s.",
	"val_nf2":"%1$s must be between %2$s and %3$s.",
	"val_nf3":"%s must be a number.",
	"val_nf4":"%1$s must be a number of at least %2$s.",
	"val_nf5":"%1$s must be a number no more than %2$s.",
	"val_nf6":"%1$s must be a number between %2$s and %3$s.",
	"val_tf0":"%s must be in the format %s.",
	"val_tf1":"%s must be an email address.",
	"val_tf2":"%1$s must contain a minimum of %2$s characters.",
	"wdtp0":"Première page",
	"wdtp1":"Page précédente",
	"wdtp10":"tous",
	"wdtp2":"Page suivante",
	"wdtp3":"Dernière page",
	"wdtp4":"Page",
	"wdtp5":"1 résultat",
	"wdtp6":"^ sur # résultats",
	"wdtp7":"^ - | sur # résultats",
	"wdtp9":"Lignes"
});
